@@ -26,14 +26,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: enable_pps.c,v 1.25 1999/05/23 19:22:04 windl Exp $
+ * $Id: enable_pps.c,v 1.28 1999/08/15 10:04:08 windl Exp $
  */
 #include	<unistd.h>
-#include	<time.h>
 #include	<stdlib.h>
 #include	<stdio.h>
+#include	<ctype.h>
 #include	<string.h>
 #include	<errno.h>
+#include	<sys/time.h>
 #include	<sys/utsname.h>
 
 #include	<linux/version.h>
@@ -42,12 +43,11 @@
 
 #include	<sys/ppsclock.h>
 
+#include	<sys/ioctl.h>
 #include	<sys/timepps.h>
 #if defined(__GNU_LIBRARY__) && __GNU_LIBRARY__ >= 6	/* libc6 or glibc2 */
 /*# warning	"Compatibility with this library has not been tested a lot!" */
-# include	<ioctl-types.h>
 #else
-# include	<sys/ioctl.h>
 				/* conflict: ioctl-types.h vs. some
 				 * linux file
 				 */
@@ -84,7 +84,7 @@
 #define	BITS_OFF(v, b)			((v) & ~(b))
 #define	BITS_ON(v, b)			((v) | (b))
 
-static	const char	id[] = "$Id: enable_pps.c,v 1.25 1999/05/23 19:22:04 windl Exp $";
+static	const char	id[] = "$Id: enable_pps.c,v 1.28 1999/08/15 10:04:08 windl Exp $";
 
 #define	BIT(n)	(1UL << (n))
 #define OPT_MONITOR		BIT(0)	/* perform monitor loop */
@@ -655,13 +655,21 @@ int	main(int argc, char *argv[])
 
 	fprintf(stderr,
 		"WARNING: This program may invalidate your system time!\n");
-	printf("(This version has been compiled in Linux %s with"
+	printf("(This version has been compiled on Linux %s with"
 #ifndef	STA_NANO
 	       "out"
 #endif
-	       " nanokernel support.\n", UTS_RELEASE);
+	       " nanokernel support\n", UTS_RELEASE);
+	printf(" using "
+#if !defined(__GNU_LIBRARY__) || __GNU_LIBRARY__ < 6
+	       "an old C library (not glibc-2.x)"
+#else
+	       "glibc-%d.%d",
+	       __GLIBC__, __GLIBC_MINOR__
+#endif
+	       );
 	uname(&un);
-	printf(" Now running %s %s)\n", un.sysname, un.release);
+	printf(". Now running %s %s)\n", un.sysname, un.release);
 	while ( (ch = getopt(argc, argv, "CeFjkMNOSt:")) != -1 )
 	{
 		switch ( ch )
